@@ -37,14 +37,15 @@ class GunicornLogger(Logger):
         log_format = self._log_format_pairs.copy()
         if self.include_request_headers:
             log_format["request_headers"] = {}
-            for k in req.headers:
+            for k in req.headers.keys():
                 log_format["request_headers"][k.lower()] = f"%({{{k.lower()}}}i)s"
 
         if self.include_response_headers:
             log_format["response_headers"] = {}
-            for k in resp.headers:
+            for k in resp.headers.keys():
                 log_format["response_headers"][k.lower()] = f"%({{{k.lower()}}}o)s"
-        if hasattr(self, "insert_custom_variables"):
+
+        if hasattr(self, "get_custom_variables"):
             cvars = self.get_custom_variables(resp, req)
             for k, value in cvars.items():
                 log_format[k.lower()] = f"%({{{k.lower()}}}e)s"
