@@ -39,7 +39,7 @@ def gcloud_trace_delegator():
 
 
 class GCloudGunicornAccesLogger(GunicornLogger):
-    """ Acces logger for flask, gunicorn and google cloud
+    """ Access logger for flask, gunicorn and google cloud
 
     Arguments:
         GunicornLogger {type} -- flask trace util GunicornLogger
